CelloSdkPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • CelloSdkPlatform
Implementers

Constructors

CelloSdkPlatform()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenEvents → Stream<CelloTokenEvent>
no setter

Methods

changeLanguage(String language) → Future<void>
getActiveUcc() → Future<Map<String, String>>
getCampaignConfig() → Future<Map<String, dynamic>>
hideFab() → Future<void>
hideWidget() → Future<void>
initialize(CelloInitializeOptions options) → Future<CelloConfiguration>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openWidget() → Future<void>
setThemeMode(String themeMode) → Future<void>
showFab() → Future<void>
shutdown() → Future<void>
toString() → String
A string representation of this object.
inherited
updateToken(String token) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ CelloSdkPlatform
getter/setter pair